## 0.0.22

This version includes the addition of outlines to the pyproject.toml file and the completion of an example notebook on doing a paper review.

### New Features

- Outlines added to pyproject.toml (d1ff517) (Eric Ma)
- Completed example notebook on doing a paper review (324d353) (Eric Ma)
